@@ -18,6 +18,8 @@ function _aws_cdk_aws_mediaconnect_CfnFlow_FailoverConfigProperty(p) {
 }
 function _aws_cdk_aws_mediaconnect_CfnFlow_SourceProperty(p) {
 }
+function _aws_cdk_aws_mediaconnect_CfnFlow_SourcePriorityProperty(p) {
+}
 function _aws_cdk_aws_mediaconnect_CfnFlowEntitlementProps(p) {
 }
 function _aws_cdk_aws_mediaconnect_CfnFlowEntitlement(p) {
@@ -78,4 +80,4 @@ class DeprecationError extends Error {
         });
     }
 }
-module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_mediaconnect_CfnFlowProps, _aws_cdk_aws_mediaconnect_CfnFlow, _aws_cdk_aws_mediaconnect_CfnFlow_EncryptionProperty, _aws_cdk_aws_mediaconnect_CfnFlow_FailoverConfigProperty, _aws_cdk_aws_mediaconnect_CfnFlow_SourceProperty, _aws_cdk_aws_mediaconnect_CfnFlowEntitlementProps, _aws_cdk_aws_mediaconnect_CfnFlowEntitlement, _aws_cdk_aws_mediaconnect_CfnFlowEntitlement_EncryptionProperty, _aws_cdk_aws_mediaconnect_CfnFlowOutputProps, _aws_cdk_aws_mediaconnect_CfnFlowOutput, _aws_cdk_aws_mediaconnect_CfnFlowOutput_EncryptionProperty, _aws_cdk_aws_mediaconnect_CfnFlowOutput_VpcInterfaceAttachmentProperty, _aws_cdk_aws_mediaconnect_CfnFlowSourceProps, _aws_cdk_aws_mediaconnect_CfnFlowSource, _aws_cdk_aws_mediaconnect_CfnFlowSource_EncryptionProperty, _aws_cdk_aws_mediaconnect_CfnFlowVpcInterfaceProps, _aws_cdk_aws_mediaconnect_CfnFlowVpcInterface };
+module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_mediaconnect_CfnFlowProps, _aws_cdk_aws_mediaconnect_CfnFlow, _aws_cdk_aws_mediaconnect_CfnFlow_EncryptionProperty, _aws_cdk_aws_mediaconnect_CfnFlow_FailoverConfigProperty, _aws_cdk_aws_mediaconnect_CfnFlow_SourceProperty, _aws_cdk_aws_mediaconnect_CfnFlow_SourcePriorityProperty, _aws_cdk_aws_mediaconnect_CfnFlowEntitlementProps, _aws_cdk_aws_mediaconnect_CfnFlowEntitlement, _aws_cdk_aws_mediaconnect_CfnFlowEntitlement_EncryptionProperty, _aws_cdk_aws_mediaconnect_CfnFlowOutputProps, _aws_cdk_aws_mediaconnect_CfnFlowOutput, _aws_cdk_aws_mediaconnect_CfnFlowOutput_EncryptionProperty, _aws_cdk_aws_mediaconnect_CfnFlowOutput_VpcInterfaceAttachmentProperty, _aws_cdk_aws_mediaconnect_CfnFlowSourceProps, _aws_cdk_aws_mediaconnect_CfnFlowSource, _aws_cdk_aws_mediaconnect_CfnFlowSource_EncryptionProperty, _aws_cdk_aws_mediaconnect_CfnFlowVpcInterfaceProps, _aws_cdk_aws_mediaconnect_CfnFlowVpcInterface };
